@@ -18,18 +18,12 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdksas.endpoint import endpoint_data
 
 class DescribeAllRegionsStatisticsRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeAllRegionsStatistics','sas')
 		self.set_method('POST')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
 
 	def get_StatusList(self):
 		return self.get_query_params().get('StatusList')
@@ -85,10 +79,10 @@ class DescribeAllRegionsStatisticsRequest(RpcRequest):
 	def set_PageSize(self,PageSize):
 		self.add_query_param('PageSize',PageSize)
 
-	def get__From(self):
+	def get_From(self):
 		return self.get_query_params().get('From')
 
-	def set__From(self,_From):
+	def set_From(self,_From):
 		self.add_query_param('From',_From)
 
 	def get_Tag(self):
